validate_document

Function validate_document 

pub fn validate_document(instance: &Value) -> Result<(), MifSchemaError>
Validates a MIF document (a JSON-LD-projected memory) against the canonical mif.schema.json.

Errors

Returns MifSchemaError::Invalid with every validation error message if instance does not conform to the schema, or MifSchemaError::SchemaCompilation if the vendored schema itself fails to compile (indicates a bug in this crate).