MifSchemaError

Enum MifSchemaError 

pub enum MifSchemaError {
    SchemaCompilation(SchemaCompilationSource),
    Invalid(Vec<String>),
    LevelFloorViolation {
        level: Level,
        missing: Vec<String>,
    },
    UnsupportedLevel(u8),
}
Error validating a MIF document or citation against the canonical schema.

Variants



SchemaCompilation(SchemaCompilationSource)

The vendored schema itself failed to compile. Indicates a bug in this crate’s vendored schema files, not a problem with the instance being validated.



Invalid(Vec<String>)

The instance failed schema validation.



LevelFloorViolation

The instance passed core schema validation but is missing fields the requested Level floor requires.

Fields

level: Level

The level floor that was requested.

missing: Vec<String>

The missing field names (dotted paths for nested fields, e.g. temporal.validFrom).



UnsupportedLevel(u8)

The requested level number is not a valid MIF level floor.

Implementations

Source

impl MifSchemaError

pub fn messages(&self) -> &[String]

The individual validation error messages if this is MifSchemaError::Invalid, or the missing field names (not full messages) if this is MifSchemaError::LevelFloorViolation. Empty for MifSchemaError::SchemaCompilation and MifSchemaError::UnsupportedLevel.