pub enum MifSchemaError {
SchemaCompilation(SchemaCompilationSource),
Invalid(Vec<String>),
}Expand description
Error validating a MIF document or citation against the canonical schema.
Variants
SchemaCompilation(SchemaCompilationSource)
The vendored schema itself failed to compile. Indicates a bug in this crate’s vendored schema files, not a problem with the instance being validated.
Invalid(Vec<String>)
The instance failed schema validation.
Implementations
Sourceimpl MifSchemaError
impl MifSchemaError
Sourcepub fn messages(&self) -> &[String]
pub fn messages(&self) -> &[String]
The individual validation error messages, if this is an
MifSchemaError::Invalid. Empty for MifSchemaError::SchemaCompilation.